.onLoad <- function(libname, pkgname) {
  keras_init() # nocov
}
